summaryrefslogtreecommitdiff
path: root/include/installmgr.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/installmgr.h')
-rw-r--r--include/installmgr.h40
1 files changed, 31 insertions, 9 deletions
diff --git a/include/installmgr.h b/include/installmgr.h
index b3972b6..56ebf7e 100644
--- a/include/installmgr.h
+++ b/include/installmgr.h
@@ -1,3 +1,25 @@
+/******************************************************************************
+ *
+ * installmgr.h - Implementation of InstallMgr
+ *
+ * $Id: installmgr.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
+ * CrossWire Bible Society
+ * P. O. Box 2528
+ * Tempe, AZ 85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ */
+
#ifndef INSTALLMGR_H
#define INSTALLMGR_H
@@ -11,7 +33,7 @@ SWORD_NAMESPACE_START
class SWMgr;
class SWModule;
class SWConfig;
-class FTPTransport;
+class RemoteTransport;
class StatusReporter;
/** A remote installation source configuration
@@ -55,19 +77,19 @@ protected:
bool passive;
SWBuf u, p;
/** override this method and provide your own custom FTPTransport subclass
*/
- virtual FTPTransport *createFTPTransport(const char *host, StatusReporter *statusReporter);
+ virtual RemoteTransport *createFTPTransport(const char *host, StatusReporter *statusReporter);
- /** override this method and provide your own custom HTTP RemoteTransport (still called FTPTransport in pre 1.7.x) subclass
+ /** override this method and provide your own custom HTTP RemoteTransport
*/
- virtual FTPTransport *createHTTPTransport(const char *host, StatusReporter *statusReporter);
+ virtual RemoteTransport *createHTTPTransport(const char *host, StatusReporter *statusReporter);
/** we have a transport member to set as current running transport so we
* can ask it to terminate below, if user requests
*/
- FTPTransport *transport;
+ RemoteTransport *transport;
public:
@@ -109,9 +131,9 @@ public:
*/
virtual int removeModule(SWMgr *manager, const char *modName);
- /** mostly an internally used method to ftp download from an remote source to a local destination
+ /** mostly an internally used method to remote download from a remote source to a local destination
*/
- virtual int ftpCopy(InstallSource *is, const char *src, const char *dest, bool dirTransfer = false, const char *suffix = "");
+ virtual int remoteCopy(InstallSource *is, const char *src, const char *dest, bool dirTransfer = false, const char *suffix = "");
/** call to install a module from a local path (fromLocation) or remote InstallSource (is) (leave the other 0)
*/
@@ -214,7 +236,7 @@ A sample implementation, roughly taken from the windows installmgr:
return false;
}
*/
- virtual bool getCipherCode(const char *modName, SWConfig *config) { return false; }
+ virtual bool getCipherCode(const char *modName, SWConfig *config) { (void) modName; (void) config; return false; }
@@ -55,19 +77,19 @@ protected:
bool passive;
SWBuf u, p;
- /** override this method and provide your own custom FTPTransport subclass
+ /** override this method and provide your own custom RemoteTransport subclass
*/